==> openshift-model-miscellaneous-6.7.2-sources.jar: io/fabric8/openshift/api/model/miscellaneous/network/operator/v1/L4RedirectRuleBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.network.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class L4RedirectRuleBuilder extends L4RedirectRuleFluentImpl<L4RedirectRuleBuilder> implements VisitableBuilder<L4RedirectRule,L4RedirectRuleBuilder>{
  public L4RedirectRuleBuilder() {
    this(false);
  }
  public L4RedirectRuleBuilder(Boolean validationEnabled) {
    this(new L4RedirectRule(), validationEnabled);
  }
  public L4RedirectRuleBuilder(L4RedirectRuleFluent<?> fluent) {
    this(fluent, false);
  }
  public L4RedirectRuleBuilder(L4RedirectRuleFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new L4RedirectRule(), validationEnabled);
  }
  public L4RedirectRuleBuilder(L4RedirectRuleFluent<?> fluent,L4RedirectRule instance) {
    this(fluent, instance, false);
  }
  public L4RedirectRuleBuilder(L4RedirectRuleFluent<?> fluent,L4RedirectRule instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withDestinationIP(instance.getDestinationIP());
      fluent.withPort(instance.getPort());
      fluent.withProtocol(instance.getProtocol());
      fluent.withTargetPort(instance.getTargetPort());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public L4RedirectRuleBuilder(L4RedirectRule instance) {
    this(instance,false);
  }
  public L4RedirectRuleBuilder(L4RedirectRule instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withDestinationIP(instance.getDestinationIP());
      this.withPort(instance.getPort());
      this.withProtocol(instance.getProtocol());
      this.withTargetPort(instance.getTargetPort());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  L4RedirectRuleFluent<?> fluent;
  Boolean validationEnabled;
  public L4RedirectRule build() {
    L4RedirectRule buildable = new L4RedirectRule(fluent.getDestinationIP(),fluent.getPort(),fluent.getProtocol(),fluent.getTargetPort());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-miscellaneous-6.8.0-sources.jar: io/fabric8/openshift/api/model/miscellaneous/network/operator/v1/L4RedirectRuleBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.network.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class L4RedirectRuleBuilder extends L4RedirectRuleFluent<L4RedirectRuleBuilder> implements VisitableBuilder<L4RedirectRule,L4RedirectRuleBuilder>{
  public L4RedirectRuleBuilder() {
    this(false);
  }
  public L4RedirectRuleBuilder(Boolean validationEnabled) {
    this(new L4RedirectRule(), validationEnabled);
  }
  public L4RedirectRuleBuilder(L4RedirectRuleFluent<?> fluent) {
    this(fluent, false);
  }
  public L4RedirectRuleBuilder(L4RedirectRuleFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new L4RedirectRule(), validationEnabled);
  }
  public L4RedirectRuleBuilder(L4RedirectRuleFluent<?> fluent,L4RedirectRule instance) {
    this(fluent, instance, false);
  }
  public L4RedirectRuleBuilder(L4RedirectRuleFluent<?> fluent,L4RedirectRule instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new L4RedirectRule());

    if (instance != null) {
      fluent.withDestinationIP(instance.getDestinationIP());
      fluent.withPort(instance.getPort());
      fluent.withProtocol(instance.getProtocol());
      fluent.withTargetPort(instance.getTargetPort());
      fluent.withDestinationIP(instance.getDestinationIP());
      fluent.withPort(instance.getPort());
      fluent.withProtocol(instance.getProtocol());
      fluent.withTargetPort(instance.getTargetPort());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public L4RedirectRuleBuilder(L4RedirectRule instance) {
    this(instance,false);
  }
  public L4RedirectRuleBuilder(L4RedirectRule instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new L4RedirectRule());

    if (instance != null) {
      this.withDestinationIP(instance.getDestinationIP());
      this.withPort(instance.getPort());
      this.withProtocol(instance.getProtocol());
      this.withTargetPort(instance.getTargetPort());
      this.withDestinationIP(instance.getDestinationIP());
      this.withPort(instance.getPort());
      this.withProtocol(instance.getProtocol());
      this.withTargetPort(instance.getTargetPort());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  L4RedirectRuleFluent<?> fluent;
  Boolean validationEnabled;
  public L4RedirectRule build() {
    L4RedirectRule buildable = new L4RedirectRule(fluent.getDestinationIP(),fluent.getPort(),fluent.getProtocol(),fluent.getTargetPort());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
